@@ -2460,3 +2460,33 @@ person_de_de <- list(
   prefixes_male = person_prefixes_male_de_de,
   suffixes = person_suffixes_de_de
 )
+
+#' @title Person Provider for German (Germany)
+#' @inherit PersonProvider description details return
+#' @export
+#' @family de
+#' @family DE
+#' @details Note for female and male components that we fall back on generic
+#' versions if the locale
+#' doesn't provide a male/female version.
+#' e.g., if no female first name we use first
+#' name
+#' @examples
+#' x <- PersonProvider_de_DE$new()
+#' x$locale
+#' x$render()
+#' x$first_name()
+#' x$first_name_female()
+#' x$first_name_male()
+#' x$last_name()
+#' x$last_name_female()
+#' x$last_name_male()
+PersonProvider_de_DE <- R6::R6Class(
+  "PersonProvider_de_DE",
+  inherit = PersonProvider,
+  private = list(
+    formats = person_formats_de_de,
+    persons = person_de_de,
+    locale_ = "de_DE"
+  )
+)
